package com.goldenwater.slaj.sins.service;

import java.util.List;
import com.goldenwater.slaj.sins.domain.RelSinsGroupToWiun;

public interface IRelSinsGroupToWiunService {
    RelSinsGroupToWiun selectRelSinsGroupToWiunByGuid(String guid);
    List<RelSinsGroupToWiun> selectRelSinsGroupToWiunList(RelSinsGroupToWiun entity);
    int insertRelSinsGroupToWiun(RelSinsGroupToWiun entity);
    int updateRelSinsGroupToWiun(RelSinsGroupToWiun entity);
    int deleteRelSinsGroupToWiunByGuid(String guid);
    int deleteRelSinsGroupToWiunByGuids(String[] guids);
}
