package com.goldenwater.slaj.sins.controller;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.goldenwater.common.annotation.Log;
import com.goldenwater.common.core.controller.BaseController;
import com.goldenwater.common.core.domain.AjaxResult;
import com.goldenwater.common.core.page.TableDataInfo;
import com.goldenwater.common.enums.BusinessType;
import com.goldenwater.common.utils.poi.ExcelUtil;
import com.goldenwater.slaj.sins.domain.RelSinsGroupToWiun;
import com.goldenwater.slaj.sins.service.IRelSinsGroupToWiunService;

@RestController
@RequestMapping("/sins/relsinsgrouptowiun")
public class RelSinsGroupToWiunController extends BaseController {
    @Autowired
    private IRelSinsGroupToWiunService relSinsGroupToWiunService;

    @GetMapping("/list")
    public TableDataInfo list(RelSinsGroupToWiun relSinsGroupToWiun) { startPage(); List<RelSinsGroupToWiun> list = relSinsGroupToWiunService.selectRelSinsGroupToWiunList(relSinsGroupToWiun); return getDataTable(list); }

    @GetMapping("/{guid}")
    public AjaxResult getInfo(@PathVariable String guid) { return AjaxResult.success(relSinsGroupToWiunService.selectRelSinsGroupToWiunByGuid(guid)); }

    @PostMapping
    public AjaxResult add(@RequestBody RelSinsGroupToWiun relSinsGroupToWiun) { return toAjax(relSinsGroupToWiunService.insertRelSinsGroupToWiun(relSinsGroupToWiun)); }

    @PutMapping
    public AjaxResult edit(@RequestBody RelSinsGroupToWiun relSinsGroupToWiun) { return toAjax(relSinsGroupToWiunService.updateRelSinsGroupToWiun(relSinsGroupToWiun)); }

    @DeleteMapping("/{guids}")
    public AjaxResult remove(@PathVariable String[] guids) { return toAjax(relSinsGroupToWiunService.deleteRelSinsGroupToWiunByGuids(guids)); }

    @Log(title = "检查组安全元素关联管理", businessType = BusinessType.EXPORT)
    @PreAuthorize("@ss.hasPermi('sins:relsinsgrouptowiun:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, RelSinsGroupToWiun relSinsGroupToWiun) { List<RelSinsGroupToWiun> list = relSinsGroupToWiunService.selectRelSinsGroupToWiunList(relSinsGroupToWiun); ExcelUtil<RelSinsGroupToWiun> util = new ExcelUtil<RelSinsGroupToWiun>(RelSinsGroupToWiun.class); util.exportExcel(response, list, "检查组安全元素关联管理数据"); }
}
